package
Version:
v0.9.0
Opens a new window with list of versions in this module.
Published: May 21, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type File struct {
Path string `json:"path"`
URI string `json:"uri"`
Type string `json:"type,omitempty"`
ApproxSize string `json:"approx_size,omitempty"`
}
type Pack struct {
ID string `json:"id"`
Name string `json:"name"`
Task string `json:"task"`
Description string `json:"description"`
BestFor string `json:"best_for"`
Files []File `json:"files"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.